@@ -20,7 +20,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: genksyms.c 1.2 Sun, 14 Jan 2001 23:06:24 +1100 kaos $"
+#ident "$Id: genksyms.c 1.4 Sun, 25 Mar 2001 21:13:48 +1000 kaos $"
 
 #include <stdio.h>
 #include <string.h>
@@ -428,6 +428,26 @@ export_symbol(const char *name)
 
 /*----------------------------------------------------------------------*/
 
+static int
+parse_kernel_version(char * p)
+{
+  int a, b, c;
+
+  a = strtoul(p, &p, 10);
+  if (*p != '.')
+    return -1;
+  b = strtoul(p+1, &p, 10);
+  if (*p != '.')
+    return -1;
+  c = strtoul(p+1, &p, 10);
+  if (*p != '\0')
+    return -1;
+
+  kernel_version = a << 16 | b << 8 | c;
+
+  return 0;
+}
+
 void
 error(const char *fmt, ...)
 {
@@ -518,22 +538,9 @@ main(int argc, char **argv)
 	flag_dump_defs = 1;
 	break;
       case 'k':
-	{
-	  char *p;
-	  int a, b, c;
-
-	  p = optarg;
-	  a = strtoul(p, &p, 10);
-	  if (*p != '.')
+	if (parse_kernel_version(optarg)) {
+	    fprintf( stderr, "unrecognised kernel version : %s\n", optarg);
 	    return -1;
-	  b = strtoul(p+1, &p, 10);
-	  if (*p != '.')
-	    return -1;
-	  c = strtoul(p+1, &p, 10);
-	  if (*p != '\0')
-	    return -1;
-
-	  kernel_version = a << 16 | b << 8 | c;
 	}
 	break;
       case 'p':
