@@ -24,7 +24,7 @@
 #ifndef MODUTILS_GENKSYMS_H
 #define MODUTILS_GENKSYMS_H 1
 
-#ident "$Id: genksyms.h 1.1 Fri, 05 Jan 2001 12:45:19 +1100 kaos $"
+#ident "$Id: genksyms.h 1.2 Sun, 14 Jan 2001 23:06:24 +1100 kaos $"
 
 #include <stdio.h>
 
@@ -47,6 +47,7 @@ struct symbol
   enum symbol_type type;
   struct string_list *defn;
   struct symbol *expansion_trail;
+  int is_extern;
 };
 
 typedef struct string_list **yystype;
@@ -66,7 +67,7 @@ extern struct string_list *current_list, *next_list;
 
 struct symbol *find_symbol(const char *name, enum symbol_type ns);
 struct symbol *add_symbol(const char *name, enum symbol_type type,
-			   struct string_list *defn);
+			   struct string_list *defn, int is_extern);
 void export_symbol(const char *);
 
 struct string_list *reset_list(void);
