@@ -42,6 +42,7 @@ char *tbtype[] =
  */
 char *aliaslist[] =
 {
+	"binfmt-0000 off",
 	"binfmt-204 binfmt_aout",
 	"binfmt-263 binfmt_aout",
 	"binfmt-264 binfmt_aout",
@@ -75,6 +76,8 @@ char *aliaslist[] =
 	"block-major-34 ide-probe-mod",
 	"block-major-37 ide-tape",
 	"block-major-44 ftl",		/* from David Woodhouse <dwmw2@infradead.org> */
+	"block-major-46 pcd",
+	"block-major-47 pf",
 	"block-major-56 ide-probe-mod",
 	"block-major-57 ide-probe-mod",
 	"block-major-58 lvm-mod",
@@ -83,6 +86,7 @@ char *aliaslist[] =
 	"block-major-90 ide-probe-mod",
 	"block-major-91 ide-probe-mod",
 	"block-major-93 nftl",		/* from David Woodhouse <dwmw2@infradead.org> */
+	"block-major-97 pg",
 
 	"char-major-4 serial",
 	"char-major-5 serial",
@@ -127,6 +131,7 @@ char *aliaslist[] =
 	"char-major-58 esp",
 	"char-major-63 kdebug",
 	"char-major-90 mtdchar",	/* from David Woodhouse <dwmw2@infradead.org> */
+	"char-major-96 pt",
 	"char-major-99 ppdev",
 	"char-major-107 3dfx", /* from Tigran Aivazian <tigran@sco.COM> */
 	"char-major-108 ppp_generic",
@@ -161,6 +166,7 @@ char *aliaslist[] =
 	"netalias-2 ip_alias",
 	"plip0 plip",
 	"plip1 plip",
+	"tunl0 ipip",
 	"cipcb0 cipcb",
 	"cipcb1 cipcb",
 	"cipcb2 cipcb",
@@ -169,6 +175,8 @@ char *aliaslist[] =
 	"ctc0 ctc",
 	"ctc1 ctc",
 	"ctc2 ctc",
+	"iucv0 netiucv",
+	"iucv1 netiucv",
 #endif
 	"ppp0 ppp",
 	"ppp1 ppp",
