@@ -131,7 +131,7 @@ void verbose(const char *ctl,...)
 		va_list list;
 		va_start(list, ctl);
 		vprintf(ctl, list);
-		va_end(list); 
+		va_end(list);
 		fflush(stdout);
 	}
 }
@@ -1108,7 +1108,7 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file, in
 		/*
 		 * prune
 		 */
-		else if (all && !assgn && strcmp(parm, "prune") == 0) {
+		else if (!assgn && strcmp(parm, "prune") == 0) {
 			decode_list(&n_prunelist, &prunelist, arg, adding, version, 0);
 			one_err = 0;
 		}
@@ -1349,9 +1349,11 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file, in
 		return ret;
 	/* else */
 
-	/* Check we have names for generated files */
-	for (i = 0; !ret && i < gen_file_count; ++i)
-		ret = gen_file_check(gen_file+i, &g, base_dir, version);
+	if (depth == 0) {
+		/* Check we have names for generated files */
+		for (i = 0; !ret && i < gen_file_count; ++i)
+			ret = gen_file_check(gen_file+i, &g, base_dir, version);
+	}
 
 	return ret;
 }
@@ -1517,7 +1519,7 @@ GLOB_LIST *config_lstmod(const char *match, const char *type, int first_only)
 	 * not be trusted.  Even in unsafe mode, only apply globbing to the
 	 * module name, not command expansion.  We trust config file input so
 	 * applying command expansion is safe, we do not trust command line input.
-	 * This assumes that the only time the user can specify -C config file 
+	 * This assumes that the only time the user can specify -C config file
 	 * is when they run under their own authority.  In particular all
 	 * mechanisms that call modprobe as root on behalf of the user must
 	 * run in safe mode, without letting the user supply a config filename.
